@@ -6,16 +6,14 @@
 #'
 #' @param market Either 'total' or 'altcoin'
 #'
-#' @importFrom jsonlite fromJSON
-#'
 #' @return Daily time series of token data in a dataframe:
 #'   \item{timestamp}{Timestamp (POSIXct)}
 #'   \item{market_cap}{Market Cap in USD}
 #'   \item{volume}{Volume traded in USD}
 #'
 #' @examples
-#' market         <- "total"
-#' crypto_global_markets <- crypto_global_market(market)
+#' market         <- 'total'
+#' crypto_global_market <- crypto_global_market(market)
 #' @export
 crypto_global_market <- function(market = NULL) {
   if (is.null(market)) {
@@ -30,10 +28,10 @@ crypto_global_market <- function(market = NULL) {
   }
 
   url <- paste0("https://graphs2.coinmarketcap.com/global/marketcap-", market)
-  df <- jsonlite::fromJSON(url, flatten = TRUE) %>% as.data.frame()
+  df <- safely_read_json(url) %>% as.data.frame()
   df[, 3] <- NULL
   names(df) <- paste0(market, "_", c("timestamp", "market_cap", "volume"))
-  df[, 1] <- as.POSIXct(as.numeric(df[, 1]) / 1000, origin = "1970-01-01", tz = "UTC")
+  df[, 1] <- as.POSIXct(as.numeric(df[, 1])/1000, origin = "1970-01-01", tz = "UTC")
   crypto_global_markets <- df %>% as.data.frame()
   return(crypto_global_markets)
 }
